OC.L10N.register(
    "settings",
    {
    "Saved" : "সংরক্ষিত",
    "Delete" : "মুছে ফেলা",
    "Get the apps to sync your files" : "আপনার ফাইল সিঙ্ক করার অ্যাপ পান",
    "Cancel" : "বাতিল করা",
    "Name" : "নাম",
    "Error" : "ভুল"
},
"nplurals=2; plural=(n != 1);");
